@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2020, Yue Du
+ * Copyright (c) 2014-2023, Yue Du
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -29,6 +29,7 @@
 
 
 #include <Python.h>
+#include <string.h>
 
 #include "xxhash.h"
 
@@ -43,16 +44,6 @@
 #define XXH128_DIGESTSIZE 16
 #define XXH128_BLOCKSIZE 64
 
-/* Release the GIL if taking more than ~10 µs */
-#define GIL_MINSIZE 100 * 1000
-
-/* Use byte string on PY2 */
-#if PY_MAJOR_VERSION < 3
-#define MyPyUnicode_FromStringAndSize PyString_FromStringAndSize
-#define PyBytes_FromStringAndSize   PyString_FromStringAndSize
-#else
-#define MyPyUnicode_FromStringAndSize PyUnicode_FromStringAndSize
-#endif
 
 /*****************************************************************************
  * Module Functions ***********************************************************
@@ -129,7 +120,7 @@ static PyObject *xxh32_hexdigest(PyObject *self, PyObject *args, PyObject *kwarg
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 /* XXH64 */
@@ -206,7 +197,7 @@ static PyObject *xxh64_hexdigest(PyObject *self, PyObject *args, PyObject *kwarg
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 /* XXH3_64 */
@@ -284,7 +275,7 @@ static PyObject *xxh3_64_hexdigest(PyObject *self, PyObject *args, PyObject *kwa
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 /* XXH3_128 */
@@ -374,7 +365,7 @@ static PyObject *xxh3_128_hexdigest(PyObject *self, PyObject *args, PyObject *kw
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 /*****************************************************************************
@@ -400,14 +391,10 @@ static void PYXXH32_dealloc(PYXXH32Object *self)
 
 static void PYXXH32_do_update(PYXXH32Object *self, Py_buffer *buf)
 {
-    if (buf->len >= GIL_MINSIZE) {
-        Py_BEGIN_ALLOW_THREADS
-        XXH32_update(self->xxhash_state, buf->buf, buf->len);
-        Py_END_ALLOW_THREADS
-    }
-    else {
-        XXH32_update(self->xxhash_state, buf->buf, buf->len);
-    }
+    Py_BEGIN_ALLOW_THREADS
+    XXH32_update(self->xxhash_state, buf->buf, buf->len);
+    Py_END_ALLOW_THREADS
+
     PyBuffer_Release(buf);
 }
 
@@ -515,7 +502,7 @@ static PyObject *PYXXH32_hexdigest(PYXXH32Object *self)
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 PyDoc_STRVAR(
@@ -588,7 +575,7 @@ PYXXH32_get_digest_size(PYXXH32Object *self, void *closure)
 static PyObject *
 PYXXH32_get_name(PYXXH32Object *self, void *closure)
 {
-    return MyPyUnicode_FromStringAndSize("XXH32", sizeof("XXH32"));
+    return PyUnicode_FromStringAndSize("XXH32", strlen("XXH32"));
 }
 
 static PyObject *
@@ -645,12 +632,7 @@ PyDoc_STRVAR(
     "copy() -- return a copy of the current xxh32 object");
 
 static PyTypeObject PYXXH32Type = {
-#if PY_MAJOR_VERSION >= 3
     PyVarObject_HEAD_INIT(NULL, 0)
-#else
-    PyObject_HEAD_INIT(NULL)
-    0,                             /* ob_size */
-#endif
     "xxhash.xxh32",                /* tp_name */
     sizeof(PYXXH32Object),         /* tp_basicsize */
     0,                             /* tp_itemsize */
@@ -710,14 +692,10 @@ static void PYXXH64_dealloc(PYXXH64Object *self)
 
 static void PYXXH64_do_update(PYXXH64Object *self, Py_buffer *buf)
 {
-    if (buf->len >= GIL_MINSIZE) {
-        Py_BEGIN_ALLOW_THREADS
-        XXH64_update(self->xxhash_state, buf->buf, buf->len);
-        Py_END_ALLOW_THREADS
-    }
-    else {
-        XXH64_update(self->xxhash_state, buf->buf, buf->len);
-    }
+    Py_BEGIN_ALLOW_THREADS
+    XXH64_update(self->xxhash_state, buf->buf, buf->len);
+    Py_END_ALLOW_THREADS
+
     PyBuffer_Release(buf);
 }
 
@@ -822,7 +800,7 @@ static PyObject *PYXXH64_hexdigest(PYXXH64Object *self)
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 
@@ -896,7 +874,7 @@ PYXXH64_get_digest_size(PYXXH64Object *self, void *closure)
 static PyObject *
 PYXXH64_get_name(PYXXH64Object *self, void *closure)
 {
-    return MyPyUnicode_FromStringAndSize("XXH64", sizeof("XXH64"));
+    return PyUnicode_FromStringAndSize("XXH64", strlen("XXH64"));
 }
 
 static PyObject *
@@ -953,12 +931,7 @@ PyDoc_STRVAR(
     "copy() -- return a copy of the current xxh64 object");
 
 static PyTypeObject PYXXH64Type = {
-#if PY_MAJOR_VERSION >= 3
     PyVarObject_HEAD_INIT(NULL, 0)
-#else
-    PyObject_HEAD_INIT(NULL)
-    0,                             /* ob_size */
-#endif
     "xxhash.xxh64",                /* tp_name */
     sizeof(PYXXH64Object),         /* tp_basicsize */
     0,                             /* tp_itemsize */
@@ -1017,14 +990,10 @@ static void PYXXH3_64_dealloc(PYXXH3_64Object *self)
 
 static void PYXXH3_64_do_update(PYXXH3_64Object *self, Py_buffer *buf)
 {
-    if (buf->len >= GIL_MINSIZE) {
-        Py_BEGIN_ALLOW_THREADS
-        XXH3_64bits_update(self->xxhash_state, buf->buf, buf->len);
-        Py_END_ALLOW_THREADS
-    }
-    else {
-        XXH3_64bits_update(self->xxhash_state, buf->buf, buf->len);
-    }
+    Py_BEGIN_ALLOW_THREADS
+    XXH3_64bits_update(self->xxhash_state, buf->buf, buf->len);
+    Py_END_ALLOW_THREADS
+
     PyBuffer_Release(buf);
 }
 
@@ -1131,7 +1100,7 @@ static PyObject *PYXXH3_64_hexdigest(PYXXH3_64Object *self)
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 
@@ -1212,7 +1181,7 @@ PYXXH3_64_get_digest_size(PYXXH3_64Object *self, void *closure)
 static PyObject *
 PYXXH3_64_get_name(PYXXH3_64Object *self, void *closure)
 {
-    return MyPyUnicode_FromStringAndSize("XXH3_64", sizeof("XXH3_64"));
+    return PyUnicode_FromStringAndSize("XXH3_64", strlen("XXH3_64"));
 }
 
 static PyObject *
@@ -1269,12 +1238,7 @@ PyDoc_STRVAR(
     "copy() -- return a copy of the current xxh64 object");
 
 static PyTypeObject PYXXH3_64Type = {
-#if PY_MAJOR_VERSION >= 3
     PyVarObject_HEAD_INIT(NULL, 0)
-#else
-    PyObject_HEAD_INIT(NULL)
-    0,                             /* ob_size */
-#endif
     "xxhash.xxh3_64",                /* tp_name */
     sizeof(PYXXH3_64Object),         /* tp_basicsize */
     0,                             /* tp_itemsize */
@@ -1334,14 +1298,10 @@ static void PYXXH3_128_dealloc(PYXXH3_128Object *self)
 
 static void PYXXH3_128_do_update(PYXXH3_128Object *self, Py_buffer *buf)
 {
-    if (buf->len >= GIL_MINSIZE) {
-        Py_BEGIN_ALLOW_THREADS
-        XXH3_128bits_update(self->xxhash_state, buf->buf, buf->len);
-        Py_END_ALLOW_THREADS
-    }
-    else {
-        XXH3_128bits_update(self->xxhash_state, buf->buf, buf->len);
-    }
+    Py_BEGIN_ALLOW_THREADS
+    XXH3_128bits_update(self->xxhash_state, buf->buf, buf->len);
+    Py_END_ALLOW_THREADS
+
     PyBuffer_Release(buf);
 }
 
@@ -1448,7 +1408,7 @@ static PyObject *PYXXH3_128_hexdigest(PYXXH3_128Object *self)
         retbuf[j++] = c;
     }
 
-    return MyPyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
+    return PyUnicode_FromStringAndSize(retbuf, sizeof(retbuf));
 }
 
 
@@ -1462,7 +1422,7 @@ static PyObject *PYXXH3_128_intdigest(PYXXH3_128Object *self)
 {
     XXH128_hash_t intdigest;
     PyObject *result, *high, *low, *sixtyfour;
-    
+
     intdigest = XXH3_128bits_digest(self->xxhash_state);
 
     sixtyfour = PyLong_FromLong(64);
@@ -1544,7 +1504,7 @@ PYXXH3_128_get_digest_size(PYXXH3_128Object *self, void *closure)
 static PyObject *
 PYXXH3_128_get_name(PYXXH3_128Object *self, void *closure)
 {
-    return MyPyUnicode_FromStringAndSize("XXH3_128", sizeof("XXH3_128"));
+    return PyUnicode_FromStringAndSize("XXH3_128", strlen("XXH3_128"));
 }
 
 static PyObject *
@@ -1601,12 +1561,7 @@ PyDoc_STRVAR(
     "copy() -- return a copy of the current xxh3_128 object");
 
 static PyTypeObject PYXXH3_128Type = {
-#if PY_MAJOR_VERSION >= 3
     PyVarObject_HEAD_INIT(NULL, 0)
-#else
-    PyObject_HEAD_INIT(NULL)
-    0,                             /* ob_size */
-#endif
     "xxhash.xxh3_128",                /* tp_name */
     sizeof(PYXXH3_128Object),         /* tp_basicsize */
     0,                             /* tp_itemsize */
@@ -1668,7 +1623,6 @@ static PyMethodDef methods[] = {
     {NULL, NULL, 0, NULL}
 };
 
-#if PY_MAJOR_VERSION >= 3
 
 static struct PyModuleDef moduledef = {
     PyModuleDef_HEAD_INIT,
@@ -1685,20 +1639,10 @@ static struct PyModuleDef moduledef = {
 #define INITERROR return NULL
 
 PyObject *PyInit__xxhash(void)
-
-#else
-#define INITERROR return
-
-void init_xxhash(void)
-#endif
 {
     PyObject *module;
 
-#if PY_MAJOR_VERSION >= 3
     module = PyModule_Create(&moduledef);
-#else
-    module = Py_InitModule("_xxhash", methods);
-#endif
 
     if (module == NULL) {
         INITERROR;
@@ -1740,7 +1684,5 @@ void init_xxhash(void)
     /* version */
     PyModule_AddStringConstant(module, "XXHASH_VERSION", VALUE_TO_STRING(XXHASH_VERSION));
 
-#if PY_MAJOR_VERSION >= 3
     return module;
-#endif
 }
